@@ -1,5 +1,5 @@
 """This module defines some python helper API for working with quantum circuits."""
 
-__all__ = ["QuantumRegistry"]
+__all__ = ["QuantumCircuit"]
 
-from .circuit_composer import QuantumRegistry
+from .circuit_composer import QuantumCircuit
